; https://github.com/llvm/llvm-project/raw/master/llvm/test/Bitcode/DIEnumerator-10.0.ll
;; DIEnumerator-10.0.ll.bc was generated by llvm-as 10.0.0
; RUN: llvm-dis < %s.bc | FileCheck %s
; RUN: verify-uselistorder < %s.bc

!named = !{!0, !1}

; CHECK: !DIEnumerator(name: "A0", value: 9223372036854775807)
!0 = !DIEnumerator(name: "A0", value: 9223372036854775807)
; CHECK: !DIEnumerator(name: "B0", value: -9223372036854775808)
!1 = !DIEnumerator(name: "B0", value: -9223372036854775808)
