<?php

  /**
  * Test file for php_count, part of SLOCCount.  This is a C-style comment.
  * This file is different from .php.
  */

  // This is a C++-style comment.

  # This is a shell-style comment.

  # Here are 9 lines of code:

  function get()
  {
    $total = 0;
    $simplestring = 'hello';
    $simplestring = '\\hello\'';
    $funkystring = "hello";
    $funkystring = "$hi\\\"";
    return 0;
  }
?>
