c     Hello World
*     Hello World
!     Hello World
      program hello
      implicit none
      print '("Hello, World!")'
      end
      ! a fancy comment
!hpf$ not a comment
!omp$ not a comment either
