{ Hello World in Pascal, for testing SLOCCount.
  This is multi-line, testing curly braces. }
(* This is another multi-line comment.
   Here's another line. *)
program Hello;
begin     (* Main *)
   writeln ('Hello, world.')
end.      (* Main *)

