{#  https://jinja.palletsprojects.com/en/2.11.x/templates/#comments #}
se.html" %}
{% block title %}Index{% endblock %}
{% block head %}
    {{ super() }}
    <style type="text/css">
        .important { color: #336699; }
  {#  </style>
{% endblock %}
{% block content %}
    <h1>Index</h1>
#}
    <p class="important">
      Welcome to my awesome homepage.
    </p>
{% endblock %}
