public class Huffman
{
    static final int[][] CODES =
        {
            /*'"' ( 34)  |11111110|01                         */        {0x3f9, 10},
            /*''' ( 39)  |11111111|010                        */        {0x7fa, 11},
        };
    // Huffman decode tree stored in a flattened char array for good
    // locality of reference.
    // Build the Huffman lookup tree and LC TABLE
}
